@@ -125,15 +125,18 @@ class ClassifyFiles(object):
                 self.images.append(i)
 
     def detectText(self, local_file):
-        local_file = self.SAVE_IMAGES_HERE + local_file
+        if self.SAVE_IMAGES_HERE[-1] == "/":
+            local_file = self.SAVE_IMAGES_HERE + local_file
+        else:
+            local_file = self.SAVE_IMAGES_HERE + "/" + local_file
+        
         textract = boto3.client('textract', region_name='ap-south-1', aws_access_key_id = 'AKIAQQPQBRYJELWOPV7A', aws_secret_access_key= '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')
-
         with open(local_file,'rb') as document:
             response = textract.detect_document_text(Document={'Bytes': document.read()})
-        text = ""
-        for item in response["Blocks"]:
-            if item["BlockType"] == "LINE":
-                text = text + " " + item["Text"]
+            text = ""
+            for item in response["Blocks"]:
+                if item["BlockType"] == "LINE":
+                    text = text + " " + item["Text"]
         
         return text
 
@@ -175,6 +178,44 @@ class ClassifyFiles(object):
         except AttributeError:
             None
 
+    def classify_DL(self, img_path):
+
+        self.decoder = {0: 'Selfie',
+                        1: 'Bank Statement',
+                        2: 'ITR_Form 16',
+                        3: 'utility',
+                        4: 'salary slip'}
+
+        def preprocess(path):
+            size = 200
+            try:
+                im = Image.open(path).resize((size,size)).convert("RGB")
+                print(im)
+            except:
+                print("Went except")
+                pass
+            X = tf.keras.utils.img_to_array(im)
+            return tf.reshape(X,[X.shape[0]//size,size,size,3])
+
+        return self.decoder[self.model.predict(preprocess(img_path)).argmax()]
+    
+    def classify_left_over_imgs(self):
+        left_over_imgs = []
+        for i in os.listdir():
+            if i.endswith("jpg"):
+                left_over_imgs.append(i)
+        
+        for img in left_over_imgs:
+            label = self.classify_DL(img)
+            print(f"{img}, {label} it is")
+            src_path = f"{self.SAVE_IMAGES_HERE}/{img}"
+            dst_path = f"{self.SAVE_IMAGES_HERE}/{label}/{img}"
+            try:
+                shutil.move(src_path, dst_path)
+            except:
+                os.mkdir(f"{self.SAVE_IMAGES_HERE}/{label}/")
+                shutil.move(src_path, dst_path)
+
     def classify(self):
         for img in self.images:
             # print(img)
@@ -184,7 +225,7 @@ class ClassifyFiles(object):
             
             try:
                 l = self.detect_pan(extracted_text)
-                if len(l) > 1 and "INCOME TAX DEPARTMENT" in l:
+                if len(l) > 1 and "INCOME TAX DEPARTMENT" in extracted_text:
                     print(img, "PAN it is")
                     src_path = f"{self.SAVE_IMAGES_HERE}/{img}"
                     dst_path = f"{self.SAVE_IMAGES_HERE}/PAN/{img}"
@@ -267,49 +308,8 @@ class ClassifyFiles(object):
             except TypeError:
                 None
 
+            self.classify_left_over_imgs()
 
-    def classify_DL(self, img_path):
-
-        self.decoder = {0: 'Aadhaar',
-            1: 'Bank Statement',
-            2: 'Cheque Leaf',
-            3: 'Licence',
-            4: 'ITR_Form 16',
-            5: 'PAN',
-            6: 'Passport',
-            7: 'salary slip',
-            8: 'utility',
-            9: 'Voter_ID'}
-
-        def preprocess(path):
-            size = 200
-            try:
-                im = Image.open(path).resize((size,size)).convert("RGB")
-                print(im)
-            except:
-                pass
-                print("Went except")
-            X = tf.keras.utils.img_to_array(im)
-            return tf.reshape(X,[X.shape[0]//size,size,size,3])
-
-        return self.decoder[self.model.predict(preprocess(img_path)).argmax()]
-    
-    def classify_left_over_imgs(self):
-        left_over_imgs = []
-        for i in os.listdir():
-            if i.endswith("jpg"):
-                left_over_imgs.append(i)
-        
-        for img in left_over_imgs:
-            label = self.classify_DL(img)
-            print(f"{img}, {label} it is")
-            src_path = f"{self.SAVE_IMAGES_HERE}/{img}"
-            dst_path = f"{self.SAVE_IMAGES_HERE}/{label}/{img}"
-            try:
-                shutil.move(src_path, dst_path)
-            except:
-                os.mkdir(f"{self.SAVE_IMAGES_HERE}/{label}/")
-                shutil.move(src_path, dst_path)
 
 
 class extract_info(object):
